#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_DIGITS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_DIGITS_HPP_INCLUDED

#include <boost/simd/constant/include/constants/digits.hpp>

#endif
